@@ -1,12 +1,12 @@
-from .utils import setup_db, create_indexes, get_db_client
 from .models import (
     DBIndex,
-    SortOrder,
-    FireOffset,
-    Operator,
-    WhereCondition,
-    WriteResult,
     DeleteResult,
     DocumentDBModel,
     DocumentDBTimeStampedModel,
+    FireOffset,
+    Operator,
+    SortOrder,
+    WhereCondition,
+    WriteResult,
 )
+from .utils import create_indexes, get_db_client, setup_db
