@@ -116,7 +116,7 @@ class GoogleStorageClient(BaseClient):
                 return None
             path_segments = path_segments[0:-1]
         else:
-            gs_uri = f"gs://{blob.bucket}/{blob.name}"
+            gs_uri = f"gs://{blob.bucket.name}/{blob.name}"
 
         name = path_segments[-1]
         path = "/".join(path_segments[0:-1])
