@@ -55,6 +55,7 @@ async def run_job(
     description: str,
     module: ScidraModule,
     job_data: dict,
+    runner: str = "csiro-swarm",
     files: List[File] = [],
     sync: bool = False,
 ) -> JobRun:
@@ -66,10 +67,20 @@ async def run_job(
     with open(os.path.join(dirname, "job.yml")) as yaml_file:
         job_yaml = yaml.safe_load(yaml_file)
 
+    job_yaml["run-job"]["tags"] = [runner]
     job_yaml["run-job"]["image"] = module.docker_image
+    job_yaml["run-job"]["variables"]["TZ"] = project.timezone
     job_yaml["run-job"]["variables"]["JOB_PARAMETERS"] = json.dumps(job_data)
     job_yaml["run-job"]["variables"]["FILE_REFS"] = json.dumps(file_refs)
     job_yaml["run-job"]["variables"]["MODULE_NAME"] = module.name
+    job_yaml["run-job"]["variables"]["KUBERNETES_CPU_REQUEST"] = module.cpu_request
+    job_yaml["run-job"]["variables"]["KUBERNETES_CPU_LIMIT"] = module.cpu_limit
+    job_yaml["run-job"]["variables"][
+        "KUBERNETES_MEMORY_REQUEST"
+    ] = f"{module.memory_request_gb}Gi"
+    job_yaml["run-job"]["variables"][
+        "KUBERNETES_MEMORY_LIMIT"
+    ] = f"{module.memory_limit_gb}Gi"
 
     client = get_workflow_client()
 
