@@ -16,8 +16,7 @@ dirname = os.path.dirname(__file__)
 test_data_path = os.path.join(dirname, "data")
 
 
-async def exercise_storage(path: str):
-    bucket_name = TEST_USER_BUCKET
+async def setup_storage(path: str):
 
     app = create_app(env_path=path)
     await start_app(app)
@@ -25,24 +24,29 @@ async def exercise_storage(path: str):
 
     assert isinstance(app, FastAPI)
     client = get_storage_client()
+    await client.make_bucket(TEST_USER_BUCKET)
+    assert await client.bucket_exists(TEST_USER_BUCKET)
+    return client
 
-    await client.make_bucket(bucket_name)
-    assert await client.bucket_exists(bucket_name)
+
+async def exercise_storage(path: str):
+
+    client = await setup_storage(path)
 
     filename = "file1.txt"
     up_file = UploadFile(
         filename=filename, file=open(os.path.join(test_data_path, filename), "rb")
     )
     # Test file upload
-    file_ref = await client.upload_file(up_file, bucket_name, "files")
+    file_ref = await client.upload_file(up_file, TEST_USER_BUCKET, "files")
     assert file_ref is not None
 
     # Test list files
-    files = await client.list_files(bucket_name, "files")
+    files = await client.list_files(TEST_USER_BUCKET, "files")
     assert files is not None and len(files) > 0
 
     # Test get file returns file correctly
-    file_stream = await client.get_file(bucket_name, "files/file1.txt")
+    file_stream = await client.get_file(TEST_USER_BUCKET, "files/file1.txt")
 
     with open(os.path.join(test_data_path, filename), "rb") as fin:
         test_file_bytes = BytesIO(fin.read())
@@ -52,15 +56,17 @@ async def exercise_storage(path: str):
         )
 
     # Test file exists Negative
-    file_stream2 = await client.file_exists(bucket_name, "files/file3.txt")
+    file_stream2 = await client.file_exists(TEST_USER_BUCKET, "files/file3.txt")
     assert file_stream2 is False
 
     # Test file exists Positive
-    file_stream2 = await client.file_exists(bucket_name, "files/file1.txt")
+    file_stream2 = await client.file_exists(TEST_USER_BUCKET, "files/file1.txt")
     assert file_stream2 is True
 
     try:
-        download_ref = await client.create_temp_file_ref(bucket_name, "files/file1.txt")
+        download_ref = await client.create_temp_file_url(
+            TEST_USER_BUCKET, "files/file1.txt"
+        )
 
         r = requests.get(download_ref.url)  # type: ignore
         target_path = Path(os.path.join(dirname, "output", download_ref.name))
@@ -73,71 +79,87 @@ async def exercise_storage(path: str):
 
     # Test Copy a file
     await client.copy_file(
-        bucket_name, "files/file1.txt", bucket_name, "files/file1_copy.txt"
+        TEST_USER_BUCKET, "files/file1.txt", TEST_USER_BUCKET, "files/file1_copy.txt"
+    )
+    file1_exists = await client.file_exists(TEST_USER_BUCKET, "files/file1.txt")
+    file1_copy_exists = await client.file_exists(
+        TEST_USER_BUCKET, "files/file1_copy.txt"
     )
-    file1_exists = await client.file_exists(bucket_name, "files/file1.txt")
-    file1_copy_exists = await client.file_exists(bucket_name, "files/file1_copy.txt")
     assert file1_exists and file1_copy_exists
 
     # Test Rename a file
-    await client.rename_file(bucket_name, "files/file1.txt", "files/file1_renamed.txt")
-    file1_exists = await client.file_exists(bucket_name, "files/file1.txt")
-    file1_r_exists = await client.file_exists(bucket_name, "files/file1_renamed.txt")
+    await client.rename_file(
+        TEST_USER_BUCKET, "files/file1.txt", "files/file1_renamed.txt"
+    )
+    file1_exists = await client.file_exists(TEST_USER_BUCKET, "files/file1.txt")
+    file1_r_exists = await client.file_exists(
+        TEST_USER_BUCKET, "files/file1_renamed.txt"
+    )
     assert file1_exists is False and file1_r_exists
 
     # Test get file returns None when file doesn't exist
-    file_stream3 = await client.get_file(bucket_name, "files/file3.txt")
+    file_stream3 = await client.get_file(TEST_USER_BUCKET, "files/file3.txt")
     assert file_stream3 is None
 
     filename = "file2.txt"
     up_file2 = UploadFile(
         filename=filename, file=open(os.path.join(test_data_path, filename), "rb")
     )
-    file_ref = await client.upload_file(up_file2, bucket_name, "files/folder")
+    file_ref = await client.upload_file(up_file2, TEST_USER_BUCKET, "files/folder")
 
     assert file_ref is not None
 
     file_ref = await client.upload_string(
-        "test_string weee", bucket_name, "files/test_string.txt"
+        "test_string weee", TEST_USER_BUCKET, "files/test_string.txt"
     )
     assert file_ref is not None
     assert await client.file_exists(
-        bucket_name, "files/test_string.txt"
+        TEST_USER_BUCKET, "files/test_string.txt"
     ), "test_string.txt Is missing from bucket"
 
     # Test folder exists
     assert await client.folder_exists(
-        bucket_name, "files/"
+        TEST_USER_BUCKET, "files/"
     ), "Folder Is missing from bucket or testing for folders is not working"
 
     # Test non existing folder does not exists
     assert not await client.folder_exists(
-        bucket_name, "files_not/"
+        TEST_USER_BUCKET, "files_not/"
     ), "Testing for non existing folder failed"
 
     # Test deleting a folder
     assert await client.file_exists(
-        bucket_name, "files/folder/file2.txt"
+        TEST_USER_BUCKET, "files/folder/file2.txt"
     ), "File2 Is missing from bucket"
-    await client.delete_file(bucket_name, "files/folder", True)
+    await client.delete_file(TEST_USER_BUCKET, "files/folder", True)
     assert not await client.file_exists(
-        bucket_name, "files/folder/file2.txt"
+        TEST_USER_BUCKET, "files/folder/file2.txt"
     ), "File2 Is in bucket when it should be deleted"
     assert not await client.file_exists(
-        bucket_name, "files/folder/"
+        TEST_USER_BUCKET, "files/folder/"
     ), "Folder still exists when it should be deleted"
 
-    await client.delete_bucket(bucket_name)
-    assert not await client.bucket_exists(bucket_name)
+    await client.delete_bucket(TEST_USER_BUCKET)
+    assert not await client.bucket_exists(TEST_USER_BUCKET)
 
     clean_env()
 
 
 @pytest.mark.asyncio
-async def test_minio_storage(minio_env_path):
-    await exercise_storage(minio_env_path)
+async def test_gcp_file_ref(env_path):
+    client = await setup_storage(env_path)
+    file_ref = await client.get_file_ref(TEST_USER_BUCKET, "files/folder/temp_file.csv")
+    assert file_ref.gs_uri is not None
+    assert not await client.file_exists(TEST_USER_BUCKET, "files/folder/temp_file.csv")
+
+    clean_env()
 
 
 @pytest.mark.asyncio
 async def test_firbase_storage(env_path):
     await exercise_storage(env_path)
+
+
+@pytest.mark.asyncio
+async def test_minio_storage(minio_env_path):
+    await exercise_storage(minio_env_path)
